FixResult class
Combined result of running all fixes on a document.
Constructors
- FixResult({required SanitizeResult sanitize, required BakeResult bake, required PropertyBakeResult propertyBake, AutoOrientBakeResult autoOrient = const AutoOrientBakeResult(layersBaked: 0, skippedLayers: [])})
-
const
Properties
- autoOrient → AutoOrientBakeResult
-
final
- bake → BakeResult
-
final
- changed → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- propertyBake → PropertyBakeResult
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sanitize → SanitizeResult
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited